markuptools.Markup
==================

.. abjad-lineage:: abjad.tools.markuptools.Markup.Markup

.. autoclass:: abjad.tools.markuptools.Markup.Markup

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.markuptools.Markup.Markup.contents
      ~abjad.tools.markuptools.Markup.Markup.direction
      ~abjad.tools.markuptools.Markup.Markup.__copy__
      ~abjad.tools.markuptools.Markup.Markup.__eq__
      ~abjad.tools.markuptools.Markup.Markup.__format__
      ~abjad.tools.markuptools.Markup.Markup.__hash__
      ~abjad.tools.markuptools.Markup.Markup.__illustrate__
      ~abjad.tools.markuptools.Markup.Markup.__ne__
      ~abjad.tools.markuptools.Markup.Markup.__repr__
      ~abjad.tools.markuptools.Markup.Markup.__str__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.markuptools.Markup.Markup.contents
   :noindex:

.. autoattribute:: abjad.tools.markuptools.Markup.Markup.direction
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.markuptools.Markup.Markup.__copy__
   :noindex:

.. automethod:: abjad.tools.markuptools.Markup.Markup.__eq__
   :noindex:

.. automethod:: abjad.tools.markuptools.Markup.Markup.__format__
   :noindex:

.. automethod:: abjad.tools.markuptools.Markup.Markup.__hash__
   :noindex:

.. automethod:: abjad.tools.markuptools.Markup.Markup.__illustrate__
   :noindex:

.. automethod:: abjad.tools.markuptools.Markup.Markup.__ne__
   :noindex:

.. automethod:: abjad.tools.markuptools.Markup.Markup.__repr__
   :noindex:

.. automethod:: abjad.tools.markuptools.Markup.Markup.__str__
   :noindex:
